@@ -1,6 +1,6 @@
 package Workflow;
 
-# $Id: Workflow.pm 361 2008-04-05 13:23:31Z jonasbn $
+# $Id: Workflow.pm 375 2008-04-22 19:54:42Z jonasbn $
 
 use strict;
 
@@ -96,7 +96,15 @@ sub execute_action {
         # the workflow; if it fails we should have some means for the
         # factory to rollback other transactions...
 
+	# Update
+	# Jim Brandt 4/16/2008: Implemented transactions for DBI persisters.
+	# Implementation still depends on each persister.
+
         FACTORY->save_workflow( $self );
+	
+	# If using a DBI persister with no autocommit, commit here.
+	FACTORY->_commit_transaction($self);
+
         $log->is_info &&
             $log->info( "Saved workflow with possible new state ok" );
     };
@@ -110,6 +118,8 @@ sub execute_action {
                      "workflow to old state '$old_state'" );
         $self->state( $old_state );
 
+	FACTORY->_rollback_transaction($self);
+
         # Don't use 'workflow_error' here since $error should already
         # be a Workflow::Exception object or subclass
 
